@@ -14,6 +14,7 @@
 # under the License.
 
 import ipaddress
+import itertools
 import os
 import socket
 import stat
@@ -24,6 +25,7 @@ import pyroute2
 import webob
 from werkzeug import exceptions
 
+from octavia.amphorae.backends.agent.api_server import util
 from octavia.common import constants as consts
 
 
@@ -76,7 +78,7 @@ class Plug(object):
 
     def plug_vip(self, vip, subnet_cidr, gateway,
                  mac_address, mtu=None, vrrp_ip=None, host_routes=(),
-                 additional_vips=()):
+                 additional_vips=(), is_sriov=False):
         vips = [{
             'ip_address': vip,
             'subnet_cidr': subnet_cidr,
@@ -88,7 +90,7 @@ class Plug(object):
             rendered_vips = self.render_vips(vips)
         except ValueError as e:
             vip_error_message = "Invalid VIP: {}".format(e)
-            return webob.Response(json=dict(message=vip_error_message),
+            return webob.Response(json={'message': vip_error_message},
                                   status=400)
 
         try:
@@ -96,7 +98,7 @@ class Plug(object):
                                              gateway, host_routes)
         except ValueError as e:
             return webob.Response(
-                json=dict(message="Invalid VRRP Address: {}".format(e)),
+                json={'message': "Invalid VRRP Address: {}".format(e)},
                 status=400)
 
         # Check if the interface is already in the network namespace
@@ -104,7 +106,7 @@ class Plug(object):
         # network namespace
         if self._netns_interface_exists(mac_address):
             return webob.Response(
-                json=dict(message="Interface already exists"), status=409)
+                json={'message': "Interface already exists"}, status=409)
 
         # Check that the interface has been fully plugged
         self._interface_by_mac(mac_address)
@@ -116,7 +118,8 @@ class Plug(object):
             interface=primary_interface,
             vips=rendered_vips,
             mtu=mtu,
-            vrrp_info=vrrp_info)
+            vrrp_info=vrrp_info,
+            is_sriov=is_sriov)
 
         # Update the list of interfaces to add to the namespace
         # This is used in the amphora reboot case to re-establish the namespace
@@ -136,9 +139,9 @@ class Plug(object):
             vips=", ".join(v['ip_address'] for v in rendered_vips)
         )
 
-        return webob.Response(json=dict(
-            message="OK",
-            details=vip_message), status=202)
+        return webob.Response(json={
+            'message': "OK",
+            'details': vip_message}, status=202)
 
     def _check_ip_addresses(self, fixed_ips):
         if fixed_ips:
@@ -149,12 +152,12 @@ class Plug(object):
                     socket.inet_pton(socket.AF_INET6, ip.get('ip_address'))
 
     def plug_network(self, mac_address, fixed_ips, mtu=None,
-                     vip_net_info=None):
+                     vip_net_info=None, is_sriov=False):
         try:
             self._check_ip_addresses(fixed_ips=fixed_ips)
         except socket.error:
-            return webob.Response(json=dict(
-                message="Invalid network port"), status=400)
+            return webob.Response(json={
+                'message': "Invalid network port"}, status=400)
 
         # Check if the interface is already in the network namespace
         # Do not attempt to re-plug the network if it is already in the
@@ -186,7 +189,8 @@ class Plug(object):
                     vips=rendered_vips,
                     mtu=mtu,
                     vrrp_info=vrrp_info,
-                    fixed_ips=fixed_ips)
+                    fixed_ips=fixed_ips,
+                    is_sriov=is_sriov)
                 self._osutils.bring_interface_up(existing_interface, 'vip')
             # Otherwise, we are just plugging a run-of-the-mill network
             else:
@@ -194,14 +198,16 @@ class Plug(object):
                 self._osutils.write_port_interface_file(
                     interface=existing_interface,
                     fixed_ips=fixed_ips,
-                    mtu=mtu)
+                    mtu=mtu, is_sriov=is_sriov)
                 self._osutils.bring_interface_up(existing_interface, 'network')
-            return webob.Response(json=dict(
-                message="OK",
-                details="Updated existing interface {interface}".format(
+
+            util.send_member_advertisements(fixed_ips)
+            return webob.Response(json={
+                'message': "OK",
+                'details': "Updated existing interface {interface}".format(
                     # TODO(rm_work): Everything in this should probably use
                     # HTTP code 200, but continuing to use 202 for consistency.
-                    interface=existing_interface)), status=202)
+                    interface=existing_interface)}, status=202)
 
         # This is the interface as it was initially plugged into the
         # default network namespace, this will likely always be eth1
@@ -209,13 +215,7 @@ class Plug(object):
 
         # We need to determine the interface name when inside the namespace
         # to avoid name conflicts
-        with pyroute2.NetNS(consts.AMPHORA_NAMESPACE,
-                            flags=os.O_CREAT) as netns:
-
-            # 1 means just loopback, but we should already have a VIP. This
-            # works for the add/delete/add case as we don't delete interfaces
-            # Note, eth0 is skipped because that is the VIP interface
-            netns_interface = 'eth{0}'.format(len(netns.get_links()))
+        netns_interface = self._netns_get_next_interface()
 
         LOG.info('Plugged interface %s will become %s in the namespace %s',
                  default_netns_interface, netns_interface,
@@ -223,7 +223,7 @@ class Plug(object):
         self._osutils.write_port_interface_file(
             interface=netns_interface,
             fixed_ips=fixed_ips,
-            mtu=mtu)
+            mtu=mtu, is_sriov=is_sriov)
 
         # Update the list of interfaces to add to the namespace
         self._update_plugged_interfaces_file(netns_interface, mac_address)
@@ -236,16 +236,19 @@ class Plug(object):
                      IFLA_IFNAME=netns_interface)
 
         self._osutils.bring_interface_up(netns_interface, 'network')
+        util.send_member_advertisements(fixed_ips)
 
-        return webob.Response(json=dict(
-            message="OK",
-            details="Plugged on interface {interface}".format(
-                interface=netns_interface)), status=202)
+        return webob.Response(json={
+            'message': "OK",
+            'details': "Plugged on interface {interface}".format(
+                interface=netns_interface)}, status=202)
 
     def _interface_by_mac(self, mac):
         try:
             with pyroute2.IPRoute() as ipr:
                 idx = ipr.link_lookup(address=mac)[0]
+                # Workaround for https://github.com/PyCQA/pylint/issues/8497
+                # pylint: disable=E1136, E1121
                 addr = ipr.get_links(idx)[0]
                 for attr in addr['attrs']:
                     if attr[0] == consts.IFLA_IFNAME:
@@ -263,8 +266,8 @@ class Plug(object):
             with os.fdopen(os.open(filename, flags), 'w') as rescan_file:
                 rescan_file.write('1')
         raise exceptions.HTTPException(
-            response=webob.Response(json=dict(
-                details="No suitable network interface found"), status=404))
+            response=webob.Response(json={
+                'details': "No suitable network interface found"}, status=404))
 
     def _update_plugged_interfaces_file(self, interface, mac_address):
         # write interfaces to plugged_interfaces file and prevent duplicates
@@ -289,3 +292,16 @@ class Plug(object):
 
     def _netns_interface_exists(self, mac_address):
         return self._netns_interface_by_mac(mac_address) is not None
+
+    def _netns_get_next_interface(self):
+        with pyroute2.NetNS(consts.AMPHORA_NAMESPACE,
+                            flags=os.O_CREAT) as netns:
+            existing_ifaces = [
+                dict(link['attrs']).get(consts.IFLA_IFNAME)
+                for link in netns.get_links()]
+            # find the first unused ethXXX
+            for idx in itertools.count(start=2):
+                iface_name = f"eth{idx}"
+                if iface_name not in existing_ifaces:
+                    break
+            return iface_name
